*** Slides BMA webinar - Spring 2024 ***
cscript
global data_directory "Please, type the name of your data directory here"
global simul_dir      "Please, type the name of your simulation directory here"
use $data_directory\data_bma_spr24

set scheme s1color

describe life_exp mrate_m mrate_f population gdp_cap ///
     forest_area  electr_r urban_pop food_prd water
notes

/* Graph for some of the series */
quietly {
  tsline dlife_exp, name(le,replace) ytitle("") ylabel(,angle(0))       ///
    title("Δ Life expectancy. Chile 1960-2020",size(small))
				 
  tsline dfood_prd, name(foodpr,replace) ytitle("") ylabel(,angle(0))   ///
    title("Δ Food production. Chile 1960-2020)",size(small))
				  
  tsline dmrate_f, name(mrate_f,replace)  ytitle("") ylabel(,angle(0))  ///
    title("Δ Female mortality rate. Chile 1960-2020",size(small))

  tsline durban_pop, name(urban,replace) ytitle("") ylabel(,angle(0))   ///
    title("Δ Urban population. Chile 1990-2020",size(small))
	
  tsline dmrate_m, name(mrate_m,replace)  ytitle("") ylabel(,angle(0))  ///
    title("Δ Male mortality rate. Chile 1960-2020",size(small))

  tsline dwater,name(water,replace) ytitle("") ylabel(,angle(0))        ///
    title("Δ Level of water stress. Chile (1993-2020)",size(small))

  tsline dforest_area,name(forest,replace) ytitle("") ylabel(,angle(0)) ///
    title("Δ Forest area. Chile (1991-2020)",size(small))
}
graph combine le foodpr mrate_f water forest mrate_m,        ///
       note("Source: The World Bank")                        ///
 caption("https://data.worldbank.org/country/chile",size(small))

/* BMA regression */	 
bmaregress dlife_exp dmrate_m dmrate_f dpopulation dgdp_cap  ///
     dforest_area  delectr_r durban_pop dfood_prd dwater,    ///
     saving($simul_dir\bma_enumerate_cl1,replace)
estimates store bmareg_enum1

/* Variable inclusion map */
bmagraph varmap, top(100) legend(rows(1))

/* Using always() option */
bmaregress dlife_exp dmrate_m dmrate_f dpopulation dgdp_cap       ///
    dforest_area  delectr_r durban_pop dwater (dfood_prd,always), ///
     saving($simul_dir\bma_enumerate_cl2,replace)
estimates store bmareg_enum2
bmagraph varmap, top(100) legend(rows(1))
bmagraph varmap, top(15) legend(rows(1))
bmagraph varmap, top(15) pipcutoff(.5) legend(rows(1))

/* Model probabilities and inclusion summary */
bmastats models
bmastats models, cumulative(.80) novartable
bmagraph pmp, cumulative xline(7 100) yline(.80 1) xlabel(7, add)
/* Model size distribution */
bmastats msize
bmagraph msize

/* Inclusion probabilities */
bmastats pip, cutoff(.50)

/* Posterior densities for coefficients */
bmagraph coefdensity {dmrate_m},name(coefd_dmrate_m,replace)         ///
   legend(size(small) rows(2) pos(3))
bmagraph coefdensity {dforest_area},name(coefd_dforest_area,replace) ///
   legend(size(small) rows(2) pos(3))
graph combine coefd_dmrate_m coefd_dforest_area,rows(2)

/* Variable inclusion dependence */
bmastats jointness dmrate_m dmrate_f durban_pop dwater ,dw

/* Comparison: bma vs regress */
// collect //
set output inform
collect clear
collect create bma_compare
collect _r_b:                                                    ///
    regress dlife_exp dmrate_m dmrate_f dpopulation dgdp_cap     ///
        dforest_area  delectr_r durban_pop dwater dfood_prd
collect _r_b=e(b_bma):                                           ///
    bmaregress dlife_exp dmrate_m dmrate_f dpopulation dgdp_cap  ///
        dforest_area  delectr_r durban_pop dwater (dfood_prd,always)

collect dims
collect label levels program_class eclass "ols" nclass "bma_reg"
collect style cell, nformat(%5.2f)
collect style header result, level(hide)
collect style column, extraspace(2)
collect style row stack,spacer

set output proc
collect layout (colname#result) (program_class)


/* Credible intervals */
estimates restore bmareg_enum2
bmacoefsample,rseed(123)
bayesstats summary

/* Sensitivity */
   /* gprior() */
    bmaregress dlife_exp dmrate_m dmrate_f dpopulation dgdp_cap      ///
       dforest_area  delectr_r durban_pop dwater (dfood_prd,always), ///
       gprior(robust) rseed(123) saving(bma_robust, replace) notable

    bmaregress dlife_exp dmrate_m dmrate_f dpopulation dgdp_cap      ///
       dforest_area  delectr_r durban_pop dwater (dfood_prd,always), ///
       gprior(robust) rseed(123) saving(bma_robust, replace) noheader
    estimates store bma_robust
   /* mprior() */
    bmaregress dlife_exp dmrate_m dmrate_f dpopulation dgdp_cap      ///
       dforest_area  delectr_r durban_pop dwater (dfood_prd,always), ///
        mprior(betabinomial 3) gprior(hyperg 3)                      ///
        rseed(123) saving(bma_mprior, replace) notable

    bmaregress dlife_exp dmrate_m dmrate_f dpopulation dgdp_cap      ///
       dforest_area  delectr_r durban_pop dwater (dfood_prd,always), ///
       mprior(betabinomial 3) gprior(hyperg 3)                       ///
       rseed(123) saving(bma_mprior, replace) noheader
    estimates store bma_mprior
    /* Convergence */
       estimates restore bma_mprior
       bmagraph pmp

   bmastats lps bmareg_enum2 bma_robust bma_mprior,compact

/* Predictions */
  /* Enumeration model */
   estimates restore bmareg_enum2
   bmapredict pmean,mean

   /* Using mrpior() and gprior() */
    estimates restore bma_mprior
    bmacoefsample,saving(bma_coef,replace)
    bmapredict pmean_simul, mean mcmcsample rseed(123)
    bmapredict cri_l cri_u, cri rseed(123)
	
summarize dlife_exp pmean* cri* if e(sample)

exit

